### R code from vignette source 'laeken-pareto.Rnw'

###################################################
### code chunk number 1: laeken-pareto.Rnw:80-81
###################################################
options(prompt="R> ")


###################################################
### code chunk number 2: laeken-pareto.Rnw:156-158 (eval = FALSE)
###################################################
## vignette("laeken-standard")
## vignette("laeken-variance")


###################################################
### code chunk number 3: laeken-pareto.Rnw:170-172
###################################################
library("laeken")
data("eusilc")


###################################################
### code chunk number 4: laeken-pareto.Rnw:240-241
###################################################
qsr("eqIncome", weights = "rb050", data = eusilc)   


###################################################
### code chunk number 5: laeken-pareto.Rnw:265-266
###################################################
gini("eqIncome", weights = "rb050", data = eusilc)


###################################################
### code chunk number 6: laeken-pareto.Rnw:298-303
###################################################
x <- seq(1, 6, length.out=1000)
dpareto <- function(x, x0 = 1, theta = 1) theta*x0^theta / x^(theta+1)
y1 <- dpareto(x, theta=1)
y2 <- dpareto(x, theta=2)
y3 <- dpareto(x, theta=3)


###################################################
### code chunk number 7: laeken-pareto.Rnw:308-318
###################################################
par(mar = c(4, 4, 0.5, 0.5) + 0.1)
plot(x, y3, type = "l", lty = 3, ylab = "f(x)", xlim = c(0.75, 6), 
    panel.first = {
        abline(h = 0, col = grey(0.75))
        abline(v = 1, col = grey(0.75))
    })
lines(x, y2, lty = 2)
lines(x, y1, lty = 1)
leg <- expression(paste(theta, " = 1"), paste(theta, " = 2"), paste(theta, " = 3"))
legend("topright", legend = leg, lty = 1:3)


###################################################
### code chunk number 8: laeken-pareto.Rnw:360-362
###################################################
hID <- eusilc$db030[which.max(eusilc$eqIncome)]
eusilc[eusilc$db030 == hID, "eqIncome"] <- 10000000


###################################################
### code chunk number 9: laeken-pareto.Rnw:371-374
###################################################
# equivalized disposable income is equal for each household
# member, therefore only one household member is taken
eusilcH <- eusilc[!duplicated(eusilc$db030), c("eqIncome", "db090")]


###################################################
### code chunk number 10: laeken-pareto.Rnw:431-433
###################################################
ts <- paretoScale(eusilcH$eqIncome, w = eusilcH$db090)
ts


###################################################
### code chunk number 11: laeken-pareto.Rnw:498-500
###################################################
# with sample weights
paretoQPlot(eusilcH$eqIncome, w = eusilcH$db090)


###################################################
### code chunk number 12: laeken-pareto.Rnw:547-549
###################################################
# with sample weights
meanExcessPlot(eusilcH$eqIncome, w = eusilcH$db090)


###################################################
### code chunk number 13: laeken-pareto.Rnw:601-605
###################################################
# using number of observations in tail
thetaHill(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaHill(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### code chunk number 14: laeken-pareto.Rnw:682-686
###################################################
# using number of observations in tail
thetaWML(eusilcH$eqIncome, k = ts$k)
# using threshold
thetaWML(eusilcH$eqIncome, x0 = ts$x0)


###################################################
### code chunk number 15: laeken-pareto.Rnw:731-735
###################################################
# using number of observations in tail
thetaISE(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaISE(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### code chunk number 16: laeken-pareto.Rnw:775-779
###################################################
# using number of observations in tail
thetaPDC(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaPDC(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### code chunk number 17: laeken-pareto.Rnw:817-819
###################################################
## gini coefficient without Pareto tail modeling
gini("eqIncome", weights = "rb050", data = eusilc)


###################################################
### code chunk number 18: laeken-pareto.Rnw:830-833
###################################################
## gini coefficient with Pareto tail modeling
fit <- paretoTail(eusilc$eqIncome, k = ts$k, 
    w = eusilc$db090, groups = eusilc$db030)


###################################################
### code chunk number 19: laeken-pareto.Rnw:843-846
###################################################
# calibration of outliers
w <- reweightOut(fit, calibVars(eusilc$db040))
gini(eusilc$eqIncome, w)


###################################################
### code chunk number 20: laeken-pareto.Rnw:854-858
###################################################
# replacement of outliers
set.seed(1234)
eqIncome <- replaceOut(fit)
gini(eqIncome, weights = eusilc$rb050)


###################################################
### code chunk number 21: laeken-pareto.Rnw:863-867
###################################################
# replacement of whole tail
set.seed(1234)
eqIncome <- replaceTail(fit)
gini(eqIncome, weights = eusilc$rb050)


